@@ -1,19 +1,10 @@
 // Copyright (C) 2020 Natanael Mojica <neithanmo@gmail.com>
 //
-// This library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
-// License as published by the Free Software Foundation; either
-// version 2 of the License, or (at your option) any later version.
+// This Source Code Form is subject to the terms of the Mozilla Public License, v2.0.
+// If a copy of the MPL was not distributed with this file, You can obtain one at
+// <https://mozilla.org/MPL/2.0/>.
 //
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-// Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public
-// License along with this library; if not, write to the
-// Free Software Foundation, Inc., 51 Franklin Street, Suite 500,
-// Boston, MA 02110-1335, USA.
+// SPDX-License-Identifier: MPL-2.0
 
 use gst::glib;
 use gst::prelude::*;
@@ -120,8 +111,9 @@ impl State {
         // pts at the beginning of the adapter.
         let samples = distance / self.in_info.bpf() as u64;
         prev_pts
-            .zip(self.samples_to_time(samples))
-            .map(|(prev_pts, time_offset)| prev_pts + time_offset)
+            .opt_checked_add(self.samples_to_time(samples))
+            .ok()
+            .flatten()
     }
 
     fn buffer_duration(&self, buffer_size: u64) -> Option<gst::ClockTime> {
@@ -346,14 +338,14 @@ impl ObjectImpl for CsoundFilter {
     fn properties() -> &'static [glib::ParamSpec] {
         static PROPERTIES: Lazy<Vec<glib::ParamSpec>> = Lazy::new(|| {
             vec![
-                glib::ParamSpec::new_boolean(
+                glib::ParamSpecBoolean::new(
                     "loop",
                     "Loop",
                     "loop over the score (can be changed in PLAYING or PAUSED state)",
                     DEFAULT_LOOP,
                     glib::ParamFlags::READWRITE | gst::PARAM_FLAG_MUTABLE_PLAYING,
                 ),
-                glib::ParamSpec::new_string(
+                glib::ParamSpecString::new(
                     "location",
                     "Location",
                     "Location of the csd file to be used by csound.
@@ -361,7 +353,7 @@ impl ObjectImpl for CsoundFilter {
                     None,
                     glib::ParamFlags::READWRITE | gst::PARAM_FLAG_MUTABLE_READY,
                 ),
-                glib::ParamSpec::new_string(
+                glib::ParamSpecString::new(
                     "csd-text",
                     "CSD-text",
                     "The content of a csd file passed as a String.
@@ -369,7 +361,7 @@ impl ObjectImpl for CsoundFilter {
                     None,
                     glib::ParamFlags::READWRITE | gst::PARAM_FLAG_MUTABLE_READY,
                 ),
-                glib::ParamSpec::new_double(
+                glib::ParamSpecDouble::new(
                     "score-offset",
                     "Score Offset",
                     "Score offset in seconds to start the performance",
@@ -445,6 +437,8 @@ impl ObjectImpl for CsoundFilter {
     }
 }
 
+impl GstObjectImpl for CsoundFilter {}
+
 impl ElementImpl for CsoundFilter {
     fn metadata() -> Option<&'static gst::subclass::ElementMetadata> {
         static ELEMENT_METADATA: Lazy<gst::subclass::ElementMetadata> = Lazy::new(|| {
@@ -461,15 +455,12 @@ impl ElementImpl for CsoundFilter {
 
     fn pad_templates() -> &'static [gst::PadTemplate] {
         static PAD_TEMPLATES: Lazy<Vec<gst::PadTemplate>> = Lazy::new(|| {
-            let caps = gst::Caps::new_simple(
-                "audio/x-raw",
-                &[
-                    ("format", &gst_audio::AUDIO_FORMAT_F64.to_str()),
-                    ("rate", &gst::IntRange::<i32>::new(1, i32::MAX)),
-                    ("channels", &gst::IntRange::<i32>::new(1, i32::MAX)),
-                    ("layout", &"interleaved"),
-                ],
-            );
+            let caps = gst::Caps::builder("audio/x-raw")
+                .field("format", gst_audio::AUDIO_FORMAT_F64.to_str())
+                .field("rate", gst::IntRange::new(1, i32::MAX))
+                .field("channels", gst::IntRange::new(1, i32::MAX))
+                .field("layout", "interleaved")
+                .build();
             let src_pad_template = gst::PadTemplate::new(
                 "src",
                 gst::PadDirection::Src,
